@@ -30,7 +30,6 @@ int optimize = FALSE;
 int histogram = FALSE;
 int interlaced = PNG_INTERLACE_LAST;
 int progress = FALSE;
-int transparent_ok = FALSE;
 int verbose = FALSE;
 int recover = FALSE;
 int webconvert = FALSE;
@@ -662,12 +661,6 @@ int processfile(char *fname, FILE *fp)
 	    fprintf(stderr, "gif2png: %s is multi-image\n", fname);
 	    return 0;
 	}
-	else if (!transparent_ok
-		 && current->imagestruct && current->imagestruct->trans != -1)
-	{
-	    fprintf(stderr, "gif2png: %s has a transparency color\n", fname);
-	    return 0;
-	}
 	else
 	{
 	    printf("%s\n", fname);
@@ -809,10 +802,6 @@ int main(int argc, char *argv[])
 		software_chunk = FALSE;
 		break;
 
-	    case 't':
-		transparent_ok = TRUE;
-		break;
-
 	    case 'v':
 		++verbose;
 		break;
